//
//  MBElasticView.m
//  UIViewBounceDemo
//
//  Created by Michael Behan on 22/09/2011.
//  Copyright 2011 Michael Behan. All rights reserved.
//

#import "MBElasticView.h"

@implementation MBElasticView
@synthesize elasticity;

-(id)initWithCoder:(NSCoder *)aDecoder
{
	elasticity = kElasticityMedium;
	return [super initWithCoder:aDecoder];
}

-(id)initWithFrame:(CGRect)frame
{
    elasticity = kElasticityMedium;
    return [super initWithFrame:frame];
}

-(void)moveTo:(CGPoint)position withDuration:(NSTimeInterval)duration
{
    CGPoint startPosition = self.center;
    CGPoint finalPosition = position;
	
	float xDistance = fabs(startPosition.x - finalPosition.x);
	float yDistance = fabs(startPosition.y - finalPosition.y);
    
	float step1x, step1y, step2x, step2y;
	
	if(startPosition.x < finalPosition.x){
		step1x = finalPosition.x + (xDistance * elasticity);
	}else{
		step1x = finalPosition.x - (xDistance * elasticity);
	}
	
	if(startPosition.y < finalPosition.y){
		step1y = finalPosition.y + (yDistance * elasticity);
	}else{
		step1y = finalPosition.y - (yDistance * elasticity);
	}
	
	if(startPosition.x < finalPosition.x){
		step2x = finalPosition.x - (xDistance * elasticity * 0.5);
	}else{
		step2x = finalPosition.x + (xDistance * elasticity * 0.5);
	}
	
	if(startPosition.y < finalPosition.y){
		step2y = finalPosition.y - (yDistance * elasticity * 0.5);
	}else{
		step2y = finalPosition.y + (yDistance * elasticity * 0.5);
	}
	
	CGPoint step1Position = CGPointMake(step1x, step1y);
    CGPoint step2Position = CGPointMake(step2x, step2y);
    
    [UIView animateWithDuration:(duration - (duration * 0.2) - (duration * 0.1))
						  delay:0
						options:UIViewAnimationCurveEaseIn
                     animations:^{self.center = step1Position;} 
                     completion:^(BOOL finished){
                         [UIView animateWithDuration:(duration * 0.2)
											   delay:0
											 options:UIViewAnimationCurveLinear
                                          animations:^{self.center = step2Position;} 
                                          completion:^(BOOL finished){
                                              [UIView animateWithDuration:(duration * 0.1)
																	delay:0
																  options:UIViewAnimationCurveEaseOut
															   animations:^{self.center = finalPosition;} 
															   completion:^(BOOL finished){
															   }];
										  }];
                     }];
}

@end
